<?php

/**
 * PHPOF2/Audit/Interface.php - PHPOF2 Audit manager interface
 *
 * (c)2001-2008 Tim Jackson (tim@timj.co.uk)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package PHPOF2
 */

interface PHPOF2_Audit_Interface
{

	const EVENT_TYPE_INSERT = 'insert';
	const EVENT_TYPE_UPDATE = 'update';
	const EVENT_TYPE_DELETE = 'delete';

	/**
	 * Record a new audit event
	 *
	 * @param string $event_type  Type of event; must be a PHPOF2_Audit_Interface::EVENT_TYPE_* constant.
	 * @param string $table_name  The table name which the event happened to
	 * @param string $pri_key     The primary key of the row in the table which the event happened to
	 * @param string $owner       The person triggering the event. Opaque string.
	 * @param string $note        Note about the event (e.g. reason for change)
	 * @param array  $changes     Array of changes made as a result of this event, where each change is in the form "column_name" => "column value after event" 
	 */
	public function recordEvent($event_type, $table_name, $pri_key, $owner, $note, array $changes);
	
} 
